<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT News directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2012.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
Name:
	news_detail_complex.cfm
Description:
	Complex Listing render handler
	Displays the category fields with links to the search filter page.
	Runs logic to validate if the fields are populated before displaying.
	Adds pagination to the listing page.
ADF App:
	PT News
History:
	2012-09-17 - MFC - Created
--->
<!--- <cfdump var="#request.params#">
<cfdump var="#cgi#"> --->
<cfscript>
	// Force dyanmic for the pagination
	request.element.isStatic = 0;
	
	newsItems = attributes.elementInfo.elementData.propertyValues;
	
	// Init the pagination variables
	itemPerPage = application.ptNews.appConfig.listing_records_per_page;
	if ( NOT StructKeyExists(request.params, "page") )
		request.params.page = 1;
	
	// Check if the News Archive filters are defined
	newsFilterURLParams = "";
	if ( StructKeyExists(request.params, "year") )
		newsFilterURLParams = ListAppend(newsFilterURLParams, "year=#request.params.year#", "&");
	if ( StructKeyExists(request.params, "month") )
		newsFilterURLParams = ListAppend(newsFilterURLParams, "month=#request.params.month#", "&");
	if ( StructKeyExists(request.params, "categoryid") )
		newsFilterURLParams = ListAppend(newsFilterURLParams, "categoryid=#request.params.categoryid#", "&");
	
	// Build the pagination data
	paginateData = application.ptNews.utils.buildPaginationStruct(page=request.params.page,
																  itemCount=ArrayLen(newsItems),
																  pageSize=itemPerPage,
																  URLparams=newsFilterURLParams);
</cfscript>
<!--- <cfdump var="#newsItems#" label="newsItems" expand="false"> --->
<!--- <cfdump var="#paginateData#" label="paginateData" expand="false"> --->

<!--- Check that we have a record to display --->
<cfif ArrayLen(newsItems)>
	<!--- <cfloop array="#newsItems#" index="currNews"> --->
	<cfloop index="newsIndex" from="#paginateData.itemStart#" to="#paginateData.itemEnd#">
		<cfscript>
			currNews = newsItems[newsIndex];
			// Get the News Category data
			categoryData = application.ptNews.newsDAO.getNewsCategoryList(categoryIDList=currNews.Values.categories);
		</cfscript>
		<!--- <cfdump var="#categoryData#"> --->
		<cfoutput>
			<h3><a href="#currNews.Values.ResolvedURL.ServerRelative#">#currNews.Values.title#</a></h3>
			<!--- Publication Date --->
			<cfif LEN(currNews.Values.publicationDate)>
				<p>#DateFormat(currNews.Values.publicationDate, "long")#</p>
			</cfif>
			<!--- Abstract --->
			<cfif LEN(currNews.Values.abstract)>
				<p>#currNews.Values.abstract#</p>
			</cfif>
			<!--- Display the Categories --->
			<cfif ArrayLen(categoryData)>
				<p>Categories:
					<cfset catsDisplayed = false>
					<cfset catListDisplay = "">
					<cfloop array="#categoryData#" index="currCat">
						<cfset listItem = '<a href="#application.ptNews.appConfig.NEWS_LISTING_PAGEURL#?categoryid=#currCat.Values.id#">#currCat.Values.name#</a>'>
						<cfset catListDisplay = ListAppend(catListDisplay, listItem, ',')>
					</cfloop>
					<!--- Fix to add a space after the commas --->
					#Replace(catListDisplay, ",", ", ", "all")#
				</p>
			</cfif>
		</cfoutput>
	</cfloop>
	<!--- Display the pagination links --->
	<cfoutput>
		<div style="width:100%;text-align:center;">
			<!--- Previous Link --->
			<cfif LEN(paginateData.prevLink)>
				<a href="#cgi.SCRIPT_NAME##paginateData.prevLink#"><< Prev</a>&nbsp;&nbsp;&nbsp;
			</cfif>
			<!--- Current Results --->
			#paginateData.resultsCount#
			<!--- Next Link --->
			<cfif LEN(paginateData.nextLink)>
				&nbsp;&nbsp;&nbsp;<a href="#cgi.SCRIPT_NAME##paginateData.nextLink#">Next >></a>
			</cfif>
		</div>
	</cfoutput>
	
<cfelse>
	<cfoutput>
		<div style="width:100%;text-align:center;">
			<p>No News Articles to Display.</p>
		</div>
	</cfoutput>
</cfif>
